Base64Decoder

Struct Base64Decoder 

pub struct Base64Decoder { /* private fields */ }
The stateful base64 decoder that supports streaming.

Implementations

Source

impl Base64Decoder

pub fn new(skip_whitespace: bool) -> Self

Create a new instance.

pub fn do_update<T: AsRef<[u8]>>( &mut self, input: T, ) -> Result<Vec<u8>, Base64Error>

Streaming API that performs Base64 encoding of the provided input, but does not apply the final padding and will hold an incomplete block while waiting for more input.

pub fn do_final<T: AsRef<[u8]>>(self, input: T) -> Result<Vec<u8>, Base64Error>

As can be expected, do_final() consumes the object.