Base64Encoder

Struct Base64Encoder 

pub struct Base64Encoder { /* private fields */ }
The stateful base64 encoder that supports streaming.

Implementations

Source

impl Base64Encoder

pub fn new() -> Self

Create a new instance.

pub fn do_update<T: AsRef<[u8]>>(&mut self, input: T) -> String

Streaming API that performs Base64 encoding of the provided input, but does not apply the final padding and will hold an incomplete block while waiting for more input.

pub fn do_final<T: AsRef<[u8]>>(self, input: T) -> String

As you would expect, do_final() consumes the object along with a final block. do_final may be called with the entire content; ie without any do_update’s before it.